/**
 * Dieser Konstruktor beinhaltet Methoden zur Fehlerbehandlung. 
 * 
 ---
 EvalError: An error in the eval() function has occurred.
 
 RangeError: Out of range number value has occurred.
 
 ReferenceError: An illegal reference has occurred.
 
 SyntaxError: A syntax error within code inside the eval() function has occurred. All other syntax errors are not caught by try/catch/finally, and will trigger the default browser error message associated with the error. To catch actual syntax errors, you may use the onerror event.
 
 TypeError: An error in the expected variable type has occurred.
 
 URIError: An error when encoding or decoding the URI has occurred (ie: when calling encodeURI()).
 
 * @namespace IM
 * @class ErrorHandler
 * @constructor 
 */
IM.ErrorHandler = function () {
    
    /**
     * Handhabt die Fehlerausgabe in der Konsole.
     * @method throwError
     * @param {String} msg Der Text der Fehlermeldung.
     * @param {String} type Gibt den Fehlertyp an (Eval-, Range-, Reference-, Syntax-, Type-, Uri-Error).
     */
    var throwError = function ( msg, type ) {
        
        switch ( type ) {
            case 'eval':
                throw EvalError( msg );
                break;
            case 'range':
                throw RangeError( msg );
                break;
            case 'ref':
                throw ReferenceError( msg );
                break;
            case 'syntax':
                throw SyntaxError( msg );
                break;
            case 'type':
                throw TypeError( msg );
                break;
            case 'uri':
                throw URIError( msg );
                break;
            default:
                throw new Error( msg );
                break;
        }
        
    };
    
    return {
        errorMsg: function ( msg, type  ) {
            
            var type = type || '',
            msg = msg || 'Fehlerbeschreibung fehlt!';
            
            throwError( msg, type );
            
        }
    };
    
}();